@@ -7,8 +7,7 @@
 
 #include "connectivitymonitor.h"
 
-#include <QDBusPendingCallWatcher>
-#include <QDBusPendingReply>
+#include <QDBusReply>
 #include <QDesktopServices>
 
 #include <KIO/OpenUrlJob>
@@ -16,6 +15,9 @@
 
 #include <NetworkManagerQt/ActiveConnection>
 
+#include <QCoroCore>
+#include <QCoroDBus>
+
 #include "plasma_nm_kded.h"
 #include <chrono>
 
@@ -62,14 +64,15 @@ void ConnectivityMonitor::connectivityChanged(NetworkManager::Connectivity conne
 
             if (m_notification) {
                 m_notification->setTitle(title);
-                m_notification->update();
+                m_notification->sendEvent();
             } else {
                 m_notification = new KNotification(QStringLiteral("CaptivePortal"), KNotification::Persistent);
-                m_notification->setActions(QStringList{i18n("Log in")});
                 m_notification->setComponentName(QStringLiteral("networkmanagement"));
                 m_notification->setTitle(title);
                 m_notification->setText(i18n("You need to log into this network"));
-                connect(m_notification, &KNotification::action1Activated, this, [this]() {
+
+                auto logInAction = m_notification->addAction(i18n("Log in"));
+                connect(logInAction, &KNotificationAction::activated, this, [this]() {
                     auto job = new KIO::OpenUrlJob(QUrl(QStringLiteral("http://networkcheck.kde.org")));
                     job->setStartupId(m_notification->xdgActivationToken().toUtf8());
                     job->start();
@@ -93,15 +96,13 @@ void ConnectivityMonitor::showLimitedConnectivityNotification()
     m_notification->sendEvent();
 }
 
-void ConnectivityMonitor::checkConnectivity()
+QCoro::Task<void> ConnectivityMonitor::checkConnectivity()
 {
-    QDBusPendingReply<uint> pendingReply = NetworkManager::checkConnectivity();
-    auto callWatcher = new QDBusPendingCallWatcher(pendingReply);
-    connect(callWatcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *watcher) {
-        QDBusPendingReply<uint> reply = *watcher;
-        if (reply.isValid()) {
-            connectivityChanged((NetworkManager::Connectivity)reply.value());
-        }
-        watcher->deleteLater();
-    });
+    QDBusReply<uint> reply = co_await NetworkManager::checkConnectivity();
+
+    if (reply.isValid()) {
+        connectivityChanged((NetworkManager::Connectivity)reply.value());
+    }
 }
+
+#include "moc_connectivitymonitor.cpp"
